//-----------------------------------------------------------------------------
//
// Title       : TCCFB_LUT
// Design      : Asynchronous_logic
// Author      : pcdemon
// Company     : NTNU
//
//-----------------------------------------------------------------------------
//
// File        : TCCFB_LUT.v
// Generated   : Tue Apr 21 09:57:33 2009
// From        : interface description file
// By          : Itf2Vhdl ver. 1.21
//
//-----------------------------------------------------------------------------
//
// Description : 
// This module describes the asynchronous LUT with associated PCHB handshake
//mechanisms described in the main report. The LUT is configued to make
//a logical computation on a given input sequence of events, and produce
// the result transmitted according to the PCHB handshake interface.
//Tis LUT structure is designed to fit into both the TCCFB and original TC
//context. For simplicity this module is a 3LUT designed to fit into an 8bit 
//register, making it possible to contain two such LUTs for the CCxBUF register.
//An extension to a 4LUT is trivial.  Inputs to the LUT is the ev_c wires.
//The output is not forked, and communicates with one event channel.
//Internal elements include the INPUT_VALID
//block, OUTPUT_VALID and INPUT_ENABLE.
//-----------------------------------------------------------------------------
`timescale 1 ns / 1 ps


module TCCFB_LUT (
// *** Input wires ****
	input wire [7:0] configuration_bits,
	input wire [2:0] ev_c_in_LUT,
	input wire [2:0] ev_d_in_LUT,
	input wire 		 r_e_LUT,
	input wire       rst,

// *** Output registers ***
	output reg       ev_c_out_LUT,
	output reg       ev_d_out_LUT,
	output reg [2:0] t_e_LUT	
	); 
	
// **** Local registers and wires ****
reg XOR_out_1;
reg XOR_out_2;
reg XOR_out_3;
reg [2:0] LUT_input;
reg LUT_output;
reg output_valid;
reg once ;
reg res_o;
reg latch_enable;
reg Latch_output_1;
reg Latch_output_2;

wire C_out;
wire input_valid;
wire input_enable;

//Instanciating the C-elements used in the PCHB environment

//C-element validating the first two input channels
c_element
	c_element_in1 (
		.a_in				(XOR_out_1),
		.b_in				(XOR_out_2),
		.s_out				(C_out)
	);

//Validates the result from the first input channels, and the third event channel	
c_element
	c_element_in2 (
		.a_in				(XOR_out_3),
		.b_in				(C_out),
		.s_out				(input_valid)
	);	
//This is the input enable control. If the input and the output is valid, the 
//input enable is valid. It is however improtant to notice that the enable
//signal from the LUT-module is the inverse of input_enable. This is
//consistent with the applied transfer protocol.
c_element
	c_element_en (
		.a_in				(input_valid),
		.b_in				(output_valid),
		.s_out				(input_enable)
	);	
	
//This block evaluates the LUT inputs according to the present configuration.
//The LUT is programmed
always @ (ev_c_in_LUT)
	begin: LOOK_UP
		LUT_input[0] = ev_c_in_LUT[0];
		LUT_input[1] = ev_c_in_LUT[1];
		LUT_input[2] = ev_c_in_LUT[2];
		
		casez(LUT_input)
			3'b 000:
				begin
				   LUT_output = configuration_bits[0];			
				end			
			3'b 001:
				begin
				   LUT_output = configuration_bits[1];	
				end
			3'b 010:
				begin
				   LUT_output = configuration_bits[2];			
				end	
				
			3'b 011:
				begin
				   LUT_output = configuration_bits[3];	
				end
			3'b 100:
				begin
				   LUT_output = configuration_bits[4];			
				end	
				
			3'b 101:
				begin
				   LUT_output = configuration_bits[5];	
				end
			3'b 110:
				begin
				   LUT_output = configuration_bits[6];			
				end	
				
			3'b 111:
				begin
				   LUT_output = configuration_bits[7];	
				end
		endcase
		
	end

//Input validation block
always 	@ (ev_c_in_LUT, ev_d_in_LUT,res_o)
	begin: INPUT_VALID
	    if (res_o == 1'b 1)
			begin
			   once = 1'b 0;
			end
		else
			begin
				XOR_out_1 = ev_c_in_LUT[0] ^ ev_d_in_LUT[0];
				XOR_out_2 = ev_c_in_LUT[1] ^ ev_d_in_LUT[1];
				XOR_out_3 = ev_c_in_LUT[2] ^ ev_d_in_LUT[2];
				once = 1'b 1;
			end
	end												  

 
//always @ (input_valid )
//	begin: VALIDATE
//		if(input_valid)
//			begin
//				once = 1'b 1;
//		end
//	end
//output valid block. Validiates the dual-rail latch output.	
always @ (Latch_output_1, Latch_output_2)
	begin: OUTPUT_VALID
			
	output_valid = Latch_output_1 | Latch_output_2;	
	end
	
always @ (input_enable,input_valid)
	begin: LATCH_enable
		//latch_enable = !(input_enable & output_valid);
		latch_enable <= #5 input_valid & !(input_enable);
	end

//Main control block for the PCHB handshake-process	
always @ (rst, latch_enable, r_e_LUT, Latch_output_1, Latch_output_2, once, LUT_output,input_enable )	
	begin: LUT_HANDSHAKE											  
				
		if (!rst)			//resetting of transmitted values and internal regs.
			begin
				ev_c_out_LUT = 1'b 0;
				ev_d_out_LUT = 1'b 0;
				t_e_LUT = 1'b 0;
				Latch_output_1 = 1'b 0;
				Latch_output_2 = 1'b 0;
			end
		else
			begin //Legal to transmit LUT value to module output	
				if ( latch_enable == 1 & r_e_LUT == 1 & once == 1 )
					begin
						Latch_output_1 = LUT_output; 
						Latch_output_2 = !(LUT_output);
						ev_c_out_LUT =  Latch_output_1;
						ev_d_out_LUT =  Latch_output_2;
						res_o = 1'b 1;  // notify that output is sent
					end
				//This state ends the handshake	
				else  if(latch_enable == 0 & r_e_LUT == 0)
					begin
						Latch_output_1 = 1'b 0; 
						Latch_output_2 = 1'b 0;	
						ev_c_out_LUT =  Latch_output_1;
						ev_d_out_LUT =  Latch_output_2;
						res_o = 1'b0;  //reset notify
					end
//The transmitted enable signals are evaluated for each pass.					
				t_e_LUT[0] = !(input_enable);
				t_e_LUT[1] = !(input_enable);
				t_e_LUT[2] = !(input_enable);	
			end
		
		
		
	end
	
	
	
endmodule
