//-----------------------------------------------------------------------------
//
// Title       : switch_block
// Design      : Asynchronous_logic
// Author      : Rune A. Bjrnerud
// Company     : NTNU / Atmel Norway
//
//-----------------------------------------------------------------------------
//
// File        : switch_block.v
// Generated   : Wed Apr 15 10:55:29 2009
// From        : interface description file
// By          : Itf2Vhdl ver. 1.21
//
//-----------------------------------------------------------------------------
//
// Description : 
// This module describes the infrastructure of a programmable cross switch,
//with 32 programming bits to control 8 WCHBs, and provide the correct
//handshake for each channel. The cross switch has 16 input channels,
//two for each of the receiving directions north and south, and 16 output
//channels for the output directions east and west. The cross switch can 
//be viewed in the appendix of the main report. Of the possible 16 input/output
//channels only 8 input/outputs can be used simultainiously,
//combined by the configuration bit sequence.
//-----------------------------------------------------------------------------
`timescale 1 ns / 1 ps

// - Local size definitions -

`define CONFIG_SIZE			32
`define INPUT_SIZE			8
`define OUTPUT_SIZE			8
`define HALF_BYTE			4
`define WCHB_CNT			8

module switch_block ( 
	
// **** Input wires ****	
	input wire  [`CONFIG_SIZE-1 : 0] configuration_bits ,  //32 configuration bits
    input wire [`INPUT_SIZE-1 : 0] ev_c_in_N,
	input wire [`INPUT_SIZE-1 : 0] ev_d_in_N,
	input wire [`INPUT_SIZE-1 : 0] ev_c_in_S,
	input wire [`INPUT_SIZE-1 : 0] ev_d_in_S,
	input wire [`INPUT_SIZE-1 : 0] r_e_W,
	input wire [`INPUT_SIZE-1 : 0] r_e_E,
	input wire rst,

	// **** Output wires and registers **** 
	output reg [`OUTPUT_SIZE-1 : 0] ev_c_out_W,
	output reg [`OUTPUT_SIZE-1 : 0] ev_d_out_W,
	output reg [`OUTPUT_SIZE-1 : 0] ev_c_out_E,
	output reg [`OUTPUT_SIZE-1 : 0] ev_d_out_E,
	output reg [`OUTPUT_SIZE-1 : 0] t_e_N,
	output reg [`OUTPUT_SIZE-1 : 0] t_e_S
	
);

// **** Internal registers and wires ****

reg [`INPUT_SIZE-1 : 0] ev_c_in_wchb;
reg [`INPUT_SIZE-1 : 0] ev_d_in_wchb;
reg [`INPUT_SIZE-1 : 0] r_e_wchb;
wire [`OUTPUT_SIZE-1 : 0] ev_c_out_wchb; 
wire [`OUTPUT_SIZE-1 : 0] ev_d_out_wchb;
wire [`OUTPUT_SIZE-1 : 0] t_e_wchb;


// - Instanciation of WCHB instances, based on configuration bits -

always @ ( configuration_bits, r_e_W, r_e_E, t_e_wchb, rst, ev_c_in_N, ev_c_in_S, ev_c_out_wchb, ev_d_out_wchb,
			ev_d_in_S, ev_d_in_N) 
  begin : GEN_CONNECTIONS 
	  
  if ( ! rst ) 	//reset of all output signals and internal registers
	  begin
		  t_e_N = 8'b 00000000;
		  t_e_S = 8'b 00000000;
		  ev_c_out_W = 8'b 00000000;
		  ev_d_out_W = 8'b 00000000;
    	  ev_c_out_E = 8'b 00000000;
		  ev_d_out_E = 8'b 00000000;
		  ev_c_in_wchb = 8'b 00000000;
		  ev_d_in_wchb = 8'b 00000000;
		  r_e_wchb = 8'b 00000000;
	  end
  else  
	  begin
// Configures the input/ output WCHB connections for Event Channel 0	  
	  	casez ( configuration_bits[3:0] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[0] = ev_c_in_N[0]; //WCHB input to north input	
					ev_d_in_wchb[0] = ev_d_in_N[0];
					r_e_wchb[0] = r_e_W[0];	// R_e from West side
					ev_c_out_W[0] = ev_c_out_wchb[0]; //Output to west side
					ev_d_out_W[0] = ev_d_out_wchb[0];
					t_e_N[0] = t_e_wchb[0];
					t_e_S[0] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[0] = 1'b 0;
					ev_d_out_E[0] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[0] = ev_c_in_S[0];
					ev_d_in_wchb[0] = ev_d_in_S[0];
					r_e_wchb[0] = r_e_W[0];
					ev_c_out_W[0] = ev_c_out_wchb[0];
					ev_d_out_W[0] = ev_d_out_wchb[0];
					t_e_S[0] = t_e_wchb[0];
					t_e_N[0] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[0] = 1'b 0;
					ev_d_out_E[0] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[0] = ev_c_in_S[0];
					ev_d_in_wchb[0] = ev_d_in_S[0];
					r_e_wchb[0] = r_e_E[0];
					ev_c_out_E[0] = ev_c_out_wchb[0];
					ev_d_out_E[0] = ev_d_out_wchb[0];
					t_e_S[0] = t_e_wchb[0];
					t_e_N[0] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[0] = 1'b 0;
					ev_d_out_W[0] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[0] = ev_c_in_N[0];
					ev_d_in_wchb[0] = ev_d_in_N[0];
					r_e_wchb[0] = r_e_E[0];
					ev_c_out_E[0] = ev_c_out_wchb[0];
					ev_d_out_E[0] = ev_d_out_wchb[0];
					t_e_N[0] = t_e_wchb[0];
					t_e_S[0] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[0] = 1'b 0;
					ev_d_out_W[0] = 1'b 0;
				end
				
		default:
				begin
					ev_c_in_wchb[0] = 1'b 0;
					ev_d_in_wchb[0] = 1'b 0;
					r_e_wchb[0]		= 1'b 0;
				end;
		endcase
// Configures the input/ output WCHB connections for Event Channel 1	  	  
		casez ( configuration_bits[7:4] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[1] = ev_c_in_N[1];
					ev_d_in_wchb[1] = ev_d_in_N[1];
					r_e_wchb[1] = r_e_W[1];
					ev_c_out_W[1] = ev_c_out_wchb[1];
					ev_d_out_W[1] = ev_d_out_wchb[1];
					t_e_N[1] = t_e_wchb[1];
					t_e_S[1] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[1] = 1'b 0;
					ev_d_out_E[1] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[1] = ev_c_in_S[1];
					ev_d_in_wchb[1] = ev_d_in_S[1];
					r_e_wchb[1] = r_e_W[1];
					ev_c_out_W[1] = ev_c_out_wchb[1];
					ev_d_out_W[1] = ev_d_out_wchb[1];
					t_e_S[1] = t_e_wchb[1];
					t_e_N[1] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[1] = 1'b 0;
					ev_d_out_E[1] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[1] = ev_c_in_S[1];
					ev_d_in_wchb[1] = ev_d_in_S[1];
					r_e_wchb[1] = r_e_E[1];
					ev_c_out_E[1] = ev_c_out_wchb[1];
					ev_d_out_E[1] = ev_d_out_wchb[1];
					t_e_S[1] = t_e_wchb[1];
					t_e_N[1] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[1] = 1'b 0;
					ev_d_out_W[1] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[1] = ev_c_in_N[1];
					ev_d_in_wchb[1] = ev_d_in_N[1];
					r_e_wchb[1] = r_e_E[1];
					ev_c_out_E[1] = ev_c_out_wchb[1];
					ev_d_out_E[1] = ev_d_out_wchb[1];
					t_e_N[1] = t_e_wchb[1];
					t_e_S[1] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[1] = 1'b 0;
					ev_d_out_W[1] = 1'b 0;
				end	
				
				default:
				begin
					ev_c_in_wchb[1] = 1'b 0;
					ev_d_in_wchb[1] = 1'b 0;
					r_e_wchb[1]		= 1'b 0;
				end;
		endcase	
// Configures the input/ output WCHB connections for Event Channel 2	  			
		
		casez ( configuration_bits[11:8] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[2] = ev_c_in_N[2];
					ev_d_in_wchb[2] = ev_d_in_N[2];
					r_e_wchb[2] = r_e_W[2];
					ev_c_out_W[2] = ev_c_out_wchb[2];
					ev_d_out_W[2] = ev_d_out_wchb[2];
					t_e_N[2] = t_e_wchb[2];
					t_e_S[2] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[2] = 1'b 0;
					ev_d_out_E[2] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[2] = ev_c_in_S[2];
					ev_d_in_wchb[2] = ev_d_in_S[2];
					r_e_wchb[2] = r_e_W[2];
					ev_c_out_W[2] = ev_c_out_wchb[2];
					ev_d_out_W[2] = ev_d_out_wchb[2];
					t_e_S[2] = t_e_wchb[2];
					t_e_N[2] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[2] = 1'b 0;
					ev_d_out_E[2] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[2] = ev_c_in_S[2];
					ev_d_in_wchb[2] = ev_d_in_S[2];
					r_e_wchb[2] = r_e_E[2];
					ev_c_out_E[2] = ev_c_out_wchb[2];
					ev_d_out_E[2] = ev_d_out_wchb[2];
					t_e_S[2] = t_e_wchb[2];
					t_e_N[2] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[2] = 1'b 0;
					ev_d_out_W[2] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[2] = ev_c_in_N[2];
					ev_d_in_wchb[2] = ev_d_in_N[2];
					r_e_wchb[2] = r_e_E[2];
					ev_c_out_E[2] = ev_c_out_wchb[2];
					ev_d_out_E[2] = ev_d_out_wchb[2];
					t_e_N[2] = t_e_wchb[2];
					t_e_S[2] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[2] = 1'b 0;
					ev_d_out_W[2] = 1'b 0;
				end	
				
			default:
				begin
					ev_c_in_wchb[2] = 1'b 0;
					ev_d_in_wchb[2] = 1'b 0;
					r_e_wchb[2]		= 1'b 0;
				end;
		endcase
// Configures the input/ output WCHB connections for Event Channel 3	  		
		casez ( configuration_bits[15:12] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[3] = ev_c_in_N[3];
					ev_d_in_wchb[3] = ev_d_in_N[3];
					r_e_wchb[3] = r_e_W[3];
					ev_c_out_W[3] = ev_c_out_wchb[3];
					ev_d_out_W[3] = ev_d_out_wchb[3];
					t_e_N[3] = t_e_wchb[3];
					t_e_S[3] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[3] = 1'b 0;
					ev_d_out_E[3] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[3] = ev_c_in_S[3];
					ev_d_in_wchb[3] = ev_d_in_S[3];
					r_e_wchb[3] = r_e_W[3];
					ev_c_out_W[3] = ev_c_out_wchb[3];
					ev_d_out_W[3] = ev_d_out_wchb[3];
					t_e_S[3] = t_e_wchb[3];
					t_e_N[3] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[3] = 1'b 0;
					ev_d_out_E[3] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[3] = ev_c_in_S[3];
					ev_d_in_wchb[3] = ev_d_in_S[3];
					r_e_wchb[3] = r_e_E[3];
					ev_c_out_E[3] = ev_c_out_wchb[3];
					ev_d_out_E[3] = ev_d_out_wchb[3];
					t_e_S[3] = t_e_wchb[3];
					t_e_N[3] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[3] = 1'b 0;
					ev_d_out_W[3] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[3] = ev_c_in_N[3];
					ev_d_in_wchb[3] = ev_d_in_N[3];
					r_e_wchb[3] = r_e_E[3];
					ev_c_out_E[3] = ev_c_out_wchb[3];
					ev_d_out_E[3] = ev_d_out_wchb[3];
					t_e_N[3] = t_e_wchb[3];
					t_e_S[3] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[3] = 1'b 0;
					ev_d_out_W[3] = 1'b 0;
				end
				
			default:
				begin
					ev_c_in_wchb[3] = 1'b 0;
					ev_d_in_wchb[3] = 1'b 0;
					r_e_wchb[3]		= 1'b 0;
				end;
		endcase
// Configures the input/ output WCHB connections for Event Channel 4	  	   
		casez ( configuration_bits[19:16] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[4] = ev_c_in_N[4];
					ev_d_in_wchb[4] = ev_d_in_N[4];
					r_e_wchb[4] = r_e_W[4];
					ev_c_out_W[4] = ev_c_out_wchb[4];
					ev_d_out_W[4] = ev_d_out_wchb[4];
					t_e_N[4] = t_e_wchb[4];
					t_e_S[4] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[4] = 1'b 0;
					ev_d_out_E[4] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[4] = ev_c_in_S[4];
					ev_d_in_wchb[4] = ev_d_in_S[4];
					r_e_wchb[4] = r_e_W[4];
					ev_c_out_W[4] = ev_c_out_wchb[4];
					ev_d_out_W[4] = ev_d_out_wchb[4];
					t_e_S[4] = t_e_wchb[4];
					t_e_N[4] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[4] = 1'b 0;
					ev_d_out_E[4] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[4] = ev_c_in_S[4];
					ev_d_in_wchb[4] = ev_d_in_S[4];
					r_e_wchb[4] = r_e_E[4];
					ev_c_out_E[4] = ev_c_out_wchb[4];
					ev_d_out_E[4] = ev_d_out_wchb[4];
					t_e_S[4] = t_e_wchb[4];
					t_e_N[4] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[4] = 1'b 0;
					ev_d_out_W[4] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[4] = ev_c_in_N[4];
					ev_d_in_wchb[4] = ev_d_in_N[4];
					r_e_wchb[4] = r_e_E[4];
					ev_c_out_E[4] = ev_c_out_wchb[4];
					ev_d_out_E[4] = ev_d_out_wchb[4];
					t_e_N[4] = t_e_wchb[4];
					t_e_S[4] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[4] = 1'b 0;
					ev_d_out_W[4] = 1'b 0;
				end
				
			default:
				begin
					ev_c_in_wchb[4] = 1'b 0;
					ev_d_in_wchb[4] = 1'b 0;
					r_e_wchb[4]		= 1'b 0;
				end;
		endcase	
// Configures the input/ output WCHB connections for Event Channel 5	  		
		casez ( configuration_bits[23:20] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[5] = ev_c_in_N[5];
					ev_d_in_wchb[5] = ev_d_in_N[5];
					r_e_wchb[5] = r_e_W[5];
					ev_c_out_W[5] = ev_c_out_wchb[5];
					ev_d_out_W[5] = ev_d_out_wchb[5];
					t_e_N[5] = t_e_wchb[5];
					t_e_S[5] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[5] = 1'b 0;
					ev_d_out_E[5] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[5] = ev_c_in_S[5];
					ev_d_in_wchb[5] = ev_d_in_S[5];
					r_e_wchb[5] = r_e_W[5];
					ev_c_out_W[5] = ev_c_out_wchb[5];
					ev_d_out_W[5] = ev_d_out_wchb[5];
					t_e_S[5] = t_e_wchb[5];
					t_e_N[5] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[5] = 1'b 0;
					ev_d_out_E[5] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[5] = ev_c_in_S[5];
					ev_d_in_wchb[5] = ev_d_in_S[5];
					r_e_wchb[5] = r_e_E[5];
					ev_c_out_E[5] = ev_c_out_wchb[5];
					ev_d_out_E[5] = ev_d_out_wchb[5];
					t_e_S[5] = t_e_wchb[5];
					t_e_N[5] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[5] = 1'b 0;
					ev_d_out_W[5] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[5] = ev_c_in_N[5];
					ev_d_in_wchb[5] = ev_d_in_N[5];
					r_e_wchb[5] = r_e_E[5];
					ev_c_out_E[5] = ev_c_out_wchb[5];
					ev_d_out_E[5] = ev_d_out_wchb[5];
					t_e_N[5] = t_e_wchb[5];
					t_e_S[5] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[5] = 1'b 0;
					ev_d_out_W[5] = 1'b 0;
				end
						
			default:
				begin
					ev_c_in_wchb[5] = 1'b 0;
					ev_d_in_wchb[5] = 1'b 0;
					r_e_wchb[5]		= 1'b 0;
				end;
		endcase	
// Configures the input/ output WCHB connections for Event Channel 6	  		
		casez ( configuration_bits[27:24] )
			4'b 0001:
				begin 		
					ev_c_in_wchb[6] = ev_c_in_N[6];
					ev_d_in_wchb[6] = ev_d_in_N[6];
					r_e_wchb[6] = r_e_W[6];
					ev_c_out_W[6] = ev_c_out_wchb[6];
					ev_d_out_W[6] = ev_d_out_wchb[6];
					t_e_N[6] = t_e_wchb[6];
					t_e_S[6] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[6] = 1'b 0;
					ev_d_out_E[6] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb[6] = ev_c_in_S[6];
					ev_d_in_wchb[6] = ev_d_in_S[6];
					r_e_wchb[6] = r_e_W[6];
					ev_c_out_W[6] = ev_c_out_wchb[6];
					ev_d_out_W[6] = ev_d_out_wchb[6];
					t_e_S[6] = t_e_wchb[6];
					t_e_N[6] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[6] = 1'b 0;
					ev_d_out_E[6] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb[6] = ev_c_in_S[6];
					ev_d_in_wchb[6] = ev_d_in_S[6];
					r_e_wchb[6] = r_e_E[6];
					ev_c_out_E[6] = ev_c_out_wchb[6];
					ev_d_out_E[6] = ev_d_out_wchb[6];
					t_e_S[6] = t_e_wchb[6];
					t_e_N[6] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[6] = 1'b 0;
					ev_d_out_W[6] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb[6] = ev_c_in_N[6];
					ev_d_in_wchb[6] = ev_d_in_N[6];
					r_e_wchb[6] = r_e_E[6];
					ev_c_out_E[6] = ev_c_out_wchb[6];
					ev_d_out_E[6] = ev_d_out_wchb[6];
					t_e_N[6] = t_e_wchb[6];
					t_e_S[6] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[6] = 1'b 0;
					ev_d_out_W[6] = 1'b 0;
				end
				
			default:
				begin
					ev_c_in_wchb[6] = 1'b 0;
					ev_d_in_wchb[6] = 1'b 0;
					r_e_wchb[6]		= 1'b 0;
				end;
		endcase	
// Configures the input/ output WCHB connections for Event Channel 7	  		
		casez ( configuration_bits[31:28] )
			4'b 0001:
				begin 		
					ev_c_in_wchb [7] = ev_c_in_N [7];
					ev_d_in_wchb [7] = ev_d_in_N [7];
					r_e_wchb [7] = r_e_W [7];
					ev_c_out_W [7] = ev_c_out_wchb [7];
					ev_d_out_W [7] = ev_d_out_wchb [7];
					t_e_N [7] = t_e_wchb [7];
					t_e_S[7] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[7] = 1'b 0;
					ev_d_out_E[7] = 1'b 0;
				end
			4'b 0010:
				begin
				   ev_c_in_wchb [7] = ev_c_in_S [7];
					ev_d_in_wchb [7] = ev_d_in_S [7];
					r_e_wchb [7] = r_e_W [7];
					ev_c_out_W [7] = ev_c_out_wchb [7];
					ev_d_out_W [7] = ev_d_out_wchb [7];
					t_e_S [7] = t_e_wchb [7];
					t_e_N[7] = 1'b 0;		//Also setting the unused channels
					ev_c_out_E[7] = 1'b 0;
					ev_d_out_E[7] = 1'b 0;
				end 
				
			4'b 0100:
				begin
				    ev_c_in_wchb [7] = ev_c_in_S [7];
					ev_d_in_wchb [7] = ev_d_in_S [7];
					r_e_wchb [7] = r_e_E [7];
					ev_c_out_E [7] = ev_c_out_wchb [7];
					ev_d_out_E [7] = ev_d_out_wchb [7];
					t_e_S [7] = t_e_wchb [7];
					t_e_N[7] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[7] = 1'b 0;
					ev_d_out_W[7] = 1'b 0;
				end
				
			4'b 1000:
				begin
				    ev_c_in_wchb [7] = ev_c_in_N [7];
					ev_d_in_wchb [7] = ev_d_in_N [7];
					r_e_wchb [7] = r_e_E [7];
					ev_c_out_E [7] = ev_c_out_wchb [7];
					ev_d_out_E [7] = ev_d_out_wchb [7];
					t_e_N [7] = t_e_wchb [7];
					t_e_S[7] = 1'b 0;		//Also setting the unused channels
					ev_c_out_W[7] = 1'b 0;
					ev_d_out_W[7] = 1'b 0;
				end
				
			default:
				begin
					ev_c_in_wchb[7] = 1'b 0;
					ev_d_in_wchb[7] = 1'b 0;
					r_e_wchb[7]		= 1'b 0;
				end;
		endcase
	  end
  end
 
// - Mapping WCHB instances to connected signals -

generate
	genvar g_i;
	for (g_i = 0; g_i <= 7; g_i = g_i +1 )
		begin: GEN_WCHBs
			if ( g_i < `WCHB_CNT )
				begin
					WCHB
						WCHB_i
						(
							.ev_c_in	(ev_c_in_wchb[g_i]),
							.ev_d_in	(ev_d_in_wchb[g_i]),
							.r_e		(r_e_wchb[g_i]),
							.rst		(rst),
							.ev_c_out   (ev_c_out_wchb[g_i]),
							.ev_d_out   (ev_d_out_wchb[g_i]),
							.t_e		(t_e_wchb[g_i])
						);
				end		
  		end
endgenerate

endmodule

`undef CONFIG_SIZE			
`undef INPUT_SIZE		
`undef OUTPUT_SIZE			
`undef HALF_BYTE			
`undef WCHB_CNT			